@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <falcon@gnuhealth.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <falcon@gnuhealth.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -22,13 +21,13 @@
 ##############################################################################
 
 from trytond.pool import Pool
-from .health_crypto import *
+from . import health_crypto
 
 
 def register():
     Pool.register(
-        PatientPrescriptionOrder,
-        BirthCertificate,
-        DeathCertificate,
-        PatientEvaluation,
+        health_crypto.PatientPrescriptionOrder,
+        health_crypto.BirthCertificate,
+        health_crypto.DeathCertificate,
+        health_crypto.PatientEvaluation,
         module='health_crypto', type_='model')
