@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -22,19 +21,19 @@
 ##############################################################################
 
 from trytond.pool import Pool
-from .health_gyneco import *
+from . import health_gyneco
 
 
 def register():
     Pool.register(
-        PatientPregnancy,
-        PrenatalEvaluation,
-        PuerperiumMonitor,
-        Perinatal,
-        PerinatalMonitor,
-        GnuHealthPatient,
-        PatientMenstrualHistory,
-        PatientMammographyHistory,
-        PatientPAPHistory,
-        PatientColposcopyHistory,
+        health_gyneco.PatientPregnancy,
+        health_gyneco.PrenatalEvaluation,
+        health_gyneco.PuerperiumMonitor,
+        health_gyneco.Perinatal,
+        health_gyneco.PerinatalMonitor,
+        health_gyneco.GnuHealthPatient,
+        health_gyneco.PatientMenstrualHistory,
+        health_gyneco.PatientMammographyHistory,
+        health_gyneco.PatientPAPHistory,
+        health_gyneco.PatientColposcopyHistory,
         module='health_gyneco', type_='model')
