@@ -1,7 +1,8 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
+#    Copyright (C) 2008-2022  Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022  GNU Solidario <health@gnusolidario.org>
 #    Copyright (C) 2011-2012  Sebastián Marró <smarro@thymbra.com>
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -20,11 +21,11 @@
 ##############################################################################
 
 from trytond.pool import Pool
-from .health_inpatient_calendar import *
+from . import health_inpatient_calendar
 
 
 def register():
     Pool.register(
-        HospitalBed,
-        InpatientRegistration,
+        health_inpatient_calendar.HospitalBed,
+        health_inpatient_calendar.InpatientRegistration,
         module='health_inpatient_calendar', type_='model')
