@@ -1,12 +1,11 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
 #
 #    INSURANCE MODULE
 #
-#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -25,16 +24,16 @@
 ##############################################################################
 
 from trytond.pool import Pool
-from .health_insurance import *
-from .wizard import *
+from . import health_insurance
+from . import wizard
 
 
 def register():
     Pool.register(
-        InsurancePlanProductPolicy,
-        InsurancePlan,
-        HealthService,
+        health_insurance.InsurancePlanProductPolicy,
+        health_insurance.InsurancePlan,
+        health_insurance.HealthService,
         module='health_insurance', type_='model')
     Pool.register(
-        CreateServiceInvoice,
+        wizard.wizard_health_insurance.CreateServiceInvoice,
         module='health_services', type_='wizard')
