@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -22,14 +21,14 @@
 ##############################################################################
 
 from trytond.pool import Pool
-from .health_pediatrics import *
+from . import health_pediatrics
 
 
 def register():
     Pool.register(
-        Newborn,
-        NeonatalApgar,
-        NeonatalMedication,
-        NeonatalCongenitalDiseases,
-        PediatricSymptomsChecklist,
+        health_pediatrics.Newborn,
+        health_pediatrics.NeonatalApgar,
+        health_pediatrics.NeonatalMedication,
+        health_pediatrics.NeonatalCongenitalDiseases,
+        health_pediatrics.PediatricSymptomsChecklist,
         module='health_pediatrics', type_='model')
